This program estimates interpolated values for 2-coordinate points given a set of points, their elevations and associated features. This method is titled Inverse Radius Weighting (IRW) which is a new interpolation technique that incorporates elevation fluctuations, thereby integrating geological context into geochemical map interpolations for enhanced geochemical interpretability.